
#--------------------------------------------------------------------------------------------------#
##### Library packages required #####
#--------------------------------------------------------------------------------------------------#

library(gridExtra)
library(zoo)
library(egg)
library(reshape2)
library(ggradar)
library(png)
library(cowplot)
library(jcolors)
library(tidyverse)
library(grid)
library(ggplotify)

library(lmtest)
library(car)
library(nlme)
library(RColorBrewer)
library(nnet)
library(haven)
library(RStat)
library(arsenal)
library(DescTools)
library(jtools)
library(gtsummary)
library(flextable)
library(officer)
library(psych)
library(gmodels)
library(expss)
library(labelled)
library(writexl)
library(tidymv)

library(MASS)
library(broom)
library(dplyr)
library(stats)
library(kza)
library(ggplot2)
library(readxl)
library(rstatix)
library(ggpubr)
library(tidyr)
library(stringr)
library(forcats)
library(utils)

#--------------------------------------------------------------------------------------------------#
##### Loading Data #####
#--------------------------------------------------------------------------------------------------#

# SET WORKING DIRECTORY
# setwd()
COVID_master_Middlesex <- read.csv("COVID_master_Middlesex_2021-11-10.csv", header=TRUE, sep = ",")
COVID_master_Middlesex$date = as.Date(COVID_master_Middlesex$date, format="%m/%d/%y")

#--------------------------------------------------------------------------------------------------#
##### Inspection of data reliability - Negative Counts #####
#--------------------------------------------------------------------------------------------------#

View(COVID_master_Middlesex %>% select(date, tests_ma, daily_tests, weekday) %>%  filter(daily_tests<0))

View(COVID_master_Middlesex %>% select(date, cases, daily_cases, weekday) %>%  filter(daily_cases<0))

View(COVID_master_Middlesex %>% select(date, deaths, daily_deaths, weekday) %>%  filter(daily_tests<0))

#--------------------------------------------------------------------------------------------------#
##### Inspection of data reliability - Systematic Zeroes #####
#--------------------------------------------------------------------------------------------------#

View(COVID_master_Middlesex %>% select(date, tests_ma, daily_tests, weekday) %>%  filter(daily_tests==0))

View(COVID_master_Middlesex %>% select(date, cases, daily_cases, weekday) %>%  filter(daily_cases==0))

View(COVID_master_Middlesex %>% select(date, deaths, daily_deaths, weekday) %>%  filter(daily_deaths==0))

#--------------------------------------------------------------------------------------------------#
##### Correction for negative reported counts #####
#--------------------------------------------------------------------------------------------------#

ind_neg_tests = which(COVID_master_Middlesex$daily_tests<0)
daily_tests_edit = COVID_master_Middlesex$daily_tests
for (i in ind_neg_tests) {
  neg_count = abs(COVID_master_Middlesex$daily_tests[i])
  # set negative value to 0
  daily_tests_edit[i] = 0 
  # subtract 1 from preceding days
  daily_tests_edit[(i-neg_count):(i-1)] = daily_tests_edit[(i-neg_count):(i-1)] - 1
}

ind_neg_cases = which(COVID_master_Middlesex$daily_cases<0)
daily_cases_edit = COVID_master_Middlesex$daily_cases
for (i in ind_neg_cases) {
  neg_count = abs(COVID_master_Middlesex$daily_cases[i])
  # set negative value to 0
  daily_cases_edit[i] = 0 
  # subtract 1 from preceding days
  daily_cases_edit[(i-neg_count):(i-1)] = daily_cases_edit[(i-neg_count):(i-1)] - 1
}

ind_neg_deaths = which(COVID_master_Middlesex$daily_deaths<0)
daily_deaths_edit = COVID_master_Middlesex$daily_deaths
for (i in ind_neg_deaths) {
  neg_count = abs(COVID_master_Middlesex$daily_deaths[i])
  daily_deaths_edit[i] = 0
  daily_deaths_edit[(i-neg_count):(i-1)] = daily_deaths_edit[(i-neg_count):(i-1)] - 1
}

COVID_master_Middlesex$daily_tests_edit = daily_tests_edit
COVID_master_Middlesex$daily_cases_edit = daily_cases_edit
COVID_master_Middlesex$daily_deaths_edit = daily_deaths_edit

#--------------------------------------------------------------------------------------------------#
##### Standardizing by population #####
#--------------------------------------------------------------------------------------------------#

COVID_master_Middlesex <- COVID_master_Middlesex %>%
  mutate(
    daily_tests_1M = (daily_tests_edit/pop_state)*1000000, # standardize by 1,000,000
    daily_cases_1M = (daily_cases_edit/pop_county)*1000000, # standardize by 1,000,000
    daily_deaths_1M = (daily_deaths_edit/pop_county)*1000000 # standardize by 1,000,000
  )

#--------------------------------------------------------------------------------------------------#
##### Application of KZ Smoother #####
#--------------------------------------------------------------------------------------------------#

## 21 Day
COVID_master_Middlesex <- COVID_master_Middlesex %>%
  mutate(tests_smooth21 = kz(daily_tests_1M, m =21, k = 3),
         cases_smooth21 = kz(daily_cases_1M, m =21, k = 3),
         deaths_smooth21 = kz(daily_deaths_1M, m = 21, k = 3))

#--------------------------------------------------------------------------------------------------#
##### Inspection of Outbreak Signature #####
#--------------------------------------------------------------------------------------------------#

## 21 Day Smoother
COVID_master_Middlesex <- COVID_master_Middlesex %>%
  mutate(
    tests_accel21 = c(0, diff(tests_smooth21)), # acceleration of tests
    cases_accel21 = c(0, diff(cases_smooth21)), # acceleration of cases
    deaths_accel21 = c(0, diff(deaths_smooth21)), # acceleration of deaths
    tests_infl21 = c(FALSE, diff(tests_accel21>0)!=0), # inflection points for tests
    cases_infl21 = c(FALSE, diff(cases_accel21>0)!=0), # inflection points for cases
    deaths_infl21 = c(FALSE, diff(deaths_accel21>0)!=0) # inflection points for deaths
  )

tests_infl_dates21 = COVID_master_Middlesex %>% filter(tests_infl21==T) %>% select(date)
cases_infl_dates21 = COVID_master_Middlesex %>% filter(cases_infl21==T) %>% select(date)
deaths_infl_dates21 = COVID_master_Middlesex %>% filter(deaths_infl21==T) %>% select(date)

#--------------------------------------------------------------------------------------------------#
##### Subsetting data for desired time interval #####
#--------------------------------------------------------------------------------------------------#

COVID_master_Middlesex_revised = filter(COVID_master_Middlesex, day>40 & day<657)

#--------------------------------------------------------------------------------------------------#
##### Creation of critical period time series variables #####
#--------------------------------------------------------------------------------------------------#

COVID_master_Middlesex_revised <- COVID_master_Middlesex_revised %>%
  mutate(
    # Tests
    CP1_tests_bi = ifelse(day <= 108, 1, 0),
    CP2_tests_bi = ifelse(day > 108 & day <= 135, 1, 0),
    CP3_tests_bi = ifelse(day > 135 & day <= 217, 1, 0),
    CP4_tests_bi = ifelse(day > 217 & day <= 248, 1, 0),
    CP5_tests_bi = ifelse(day > 248 & day <= 320, 1, 0),
    CP6_tests_bi = ifelse(day > 320 & day <= 414, 1, 0),
    CP7_tests_bi = ifelse(day > 414 & day <= 439, 1, 0),
    CP8_tests_bi = ifelse(day > 439 & day <= 523, 1, 0),
    CP9_tests_bi = ifelse(day > 523 & day <= 603, 1, 0),
    CP10_tests_bi = ifelse(day > 603, 1, 0),
    # Cases
    CP1_cases_bi = ifelse(day <= 90, 1, 0),
    CP2_cases_bi = ifelse(day > 90 & day <= 165, 1, 0),
    CP3_cases_bi = ifelse(day > 165 & day <= 347, 1, 0),
    CP4_cases_bi = ifelse(day > 347 & day <= 406, 1, 0),
    CP5_cases_bi = ifelse(day > 406 & day <= 436, 1, 0),
    CP6_cases_bi = ifelse(day > 436 & day <= 519, 1, 0),
    CP7_cases_bi = ifelse(day > 519 & day <= 600, 1, 0),
    CP8_cases_bi = ifelse(day > 600, 1, 0),
    # Deaths
    CP1_deaths_bi = ifelse(day <= 100, 1, 0),
    CP2_deaths_bi = ifelse(day > 100 & day <= 200, 1, 0),
    CP3_deaths_bi = ifelse(day > 200 & day <= 235, 1, 0),
    CP4_deaths_bi = ifelse(day > 235 & day <= 360, 1, 0),
    CP5_deaths_bi = ifelse(day > 360 & day <= 533, 1, 0),
    CP6_deaths_bi = ifelse(day > 533 & day <= 558, 1, 0),
    CP7_deaths_bi = ifelse(day > 558 & day <= 619, 1, 0),
    CP8_deaths_bi = ifelse(day > 619, 1, 0)
  )

# create critical period variables
COVID_master_Middlesex_revised <- COVID_master_Middlesex_revised %>%
  mutate(
    CP_tests_all = case_when(
      CP1_tests_bi == 1 ~ "CP01",
      CP2_tests_bi == 1 ~ "CP02",
      CP3_tests_bi == 1 ~ "CP03",
      CP4_tests_bi == 1 ~ "CP04",
      CP5_tests_bi == 1 ~ "CP05",
      CP6_tests_bi == 1 ~ "CP06",
      CP7_tests_bi == 1 ~ "CP07",
      CP8_tests_bi == 1 ~ "CP08",
      CP9_tests_bi == 1 ~ "CP09",
      CP10_tests_bi == 1 ~ "CP10"
    ),
    CP_cases_all = case_when(
      CP1_cases_bi == 1 ~ "CP01",
      CP2_cases_bi == 1 ~ "CP02",
      CP3_cases_bi == 1 ~ "CP03",
      CP4_cases_bi == 1 ~ "CP04",
      CP5_cases_bi == 1 ~ "CP05",
      CP6_cases_bi == 1 ~ "CP06",
      CP7_cases_bi == 1 ~ "CP07",
      CP8_cases_bi == 1 ~ "CP08"
    ),
    CP_deaths_all = case_when(
      CP1_deaths_bi == 1 ~ "CP01",
      CP2_deaths_bi == 1 ~ "CP02",
      CP3_deaths_bi == 1 ~ "CP03",
      CP4_deaths_bi == 1 ~ "CP04",
      CP5_deaths_bi == 1 ~ "CP05",
      CP6_deaths_bi == 1 ~ "CP06",
      CP7_deaths_bi == 1 ~ "CP07",
      CP8_deaths_bi == 1 ~ "CP08"
    )
  )

# Calculate number of days in each critical period

CP_ndays_tests = COVID_master_Middlesex_revised %>%
  group_by(CP_tests_all) %>%
  summarise(ndays = n())

CP_ndays_cases = COVID_master_Middlesex_revised %>%
  group_by(CP_cases_all) %>%
  summarise(ndays = n())

CP_ndays_deaths = COVID_master_Middlesex_revised %>%
  group_by(CP_deaths_all) %>%
  summarise(ndays = n())

# create time series variables for critical periods for cases and deaths separately.
COVID_master_Middlesex_revised <- COVID_master_Middlesex_revised %>%
  mutate(
    T1T_ts = row_number(),
    T2T_ts = T1T_ts - CP_ndays_tests$ndays[1],
    T2T_ts = ifelse(T2T_ts < 0, 0, T2T_ts),
    T3T_ts = T1T_ts - sum(CP_ndays_tests$ndays[1:2]),
    T3T_ts = ifelse(T3T_ts < 0, 0, T3T_ts),
    T4T_ts = T1T_ts - sum(CP_ndays_tests$ndays[1:3]),
    T4T_ts = ifelse(T4T_ts < 0, 0, T4T_ts),
    T5T_ts = T1T_ts - sum(CP_ndays_tests$ndays[1:4]),
    T5T_ts = ifelse(T5T_ts < 0, 0, T5T_ts),
    T6T_ts = T1T_ts - sum(CP_ndays_tests$ndays[1:5]),
    T6T_ts = ifelse(T6T_ts < 0, 0, T6T_ts),
    T7T_ts = T1T_ts - sum(CP_ndays_tests$ndays[1:6]),
    T7T_ts = ifelse(T7T_ts < 0, 0, T7T_ts),
    T8T_ts = T1T_ts - sum(CP_ndays_tests$ndays[1:7]),
    T8T_ts = ifelse(T8T_ts < 0, 0, T8T_ts),
    T9T_ts = T1T_ts - sum(CP_ndays_tests$ndays[1:8]),
    T9T_ts = ifelse(T9T_ts < 0, 0, T9T_ts),
    T10T_ts = T1T_ts - sum(CP_ndays_tests$ndays[1:9]),
    T10T_ts = ifelse(T10T_ts < 0, 0, T10T_ts)
  )%>%
  mutate(
    T1C_ts = row_number(),
    T2C_ts = T1C_ts - CP_ndays_cases$ndays[1],
    T2C_ts = ifelse(T2C_ts < 0, 0, T2C_ts),
    T3C_ts = T1C_ts - sum(CP_ndays_cases$ndays[1:2]),
    T3C_ts = ifelse(T3C_ts < 0, 0, T3C_ts),
    T4C_ts = T1C_ts - sum(CP_ndays_cases$ndays[1:3]),
    T4C_ts = ifelse(T4C_ts < 0, 0, T4C_ts),
    T5C_ts = T1C_ts - sum(CP_ndays_cases$ndays[1:4]),
    T5C_ts = ifelse(T5C_ts < 0, 0, T5C_ts),
    T6C_ts = T1C_ts - sum(CP_ndays_cases$ndays[1:5]),
    T6C_ts = ifelse(T6C_ts < 0, 0, T6C_ts),
    T7C_ts = T1C_ts - sum(CP_ndays_cases$ndays[1:6]),
    T7C_ts = ifelse(T7C_ts < 0, 0, T7C_ts),
    T8C_ts = T1C_ts - sum(CP_ndays_cases$ndays[1:7]),
    T8C_ts = ifelse(T8C_ts < 0, 0, T8C_ts)
  ) %>%
  mutate(
    T1D_ts = row_number(),
    T2D_ts = T1D_ts - CP_ndays_deaths$ndays[1],
    T2D_ts = ifelse(T2D_ts < 0, 0, T2D_ts),
    T3D_ts = T1D_ts - sum(CP_ndays_deaths$ndays[1:2]),
    T3D_ts = ifelse(T3D_ts < 0, 0, T3D_ts),
    T4D_ts = T1D_ts - sum(CP_ndays_deaths$ndays[1:3]),
    T4D_ts = ifelse(T4D_ts < 0, 0, T4D_ts),
    T5D_ts = T1D_ts - sum(CP_ndays_deaths$ndays[1:4]),
    T5D_ts = ifelse(T5D_ts < 0, 0, T5D_ts),
    T6D_ts = T1D_ts - sum(CP_ndays_deaths$ndays[1:5]),
    T6D_ts = ifelse(T6D_ts < 0, 0, T6D_ts),
    T7D_ts = T1D_ts - sum(CP_ndays_deaths$ndays[1:6]),
    T7D_ts = ifelse(T7D_ts < 0, 0, T7D_ts),
    T8D_ts = T1D_ts - sum(CP_ndays_deaths$ndays[1:7]),
    T8D_ts = ifelse(T8D_ts < 0, 0, T8D_ts)
  )

#--------------------------------------------------------------------------------------------------#
##### Creation of policy phase and stringency variables #####
#--------------------------------------------------------------------------------------------------#

COVID_master_Middlesex_revised <- COVID_master_Middlesex_revised %>%
  mutate(
    phase = case_when(
      date <= "2020-03-14" ~ "A",
      date >"2020-03-14" & date <= "2020-05-17" ~ "B",
      date > "2020-05-17" & date <= "2020-07-01" ~ "C",
      date > "2020-07-01" & date <= "2020-09-28" ~ "D",
      date > "2020-09-28" & date <= "2020-12-07" ~ "E",
      date > "2020-12-07" & date <= "2021-02-24" ~ "F",
      date > "2021-02-24" & date <= "2021-03-17" ~ "G",
      date > "2021-03-17" & date <= "2021-05-27" ~ "H",
      date > "2021-05-27" ~ "I"),
    stringency = case_when(
      phase == "A" ~ 0,
      phase == "B" ~ 5,
      phase == "C" ~ 4,
      phase == "D" ~ 3,
      phase == "E" ~ 2,
      phase == "F" ~ 3,
      phase == "G" ~ 2,
      phase == "H" ~ 1,
      phase == "I" ~ 0
    )
  )
  
#--------------------------------------------------------------------------------------------------#
##### Exporting to Excel final dataset #####
#--------------------------------------------------------------------------------------------------#

COVID_master_Middlesex_revised = subset(COVID_master_Middlesex_revised, select=-c(day))
write.csv(COVID_master_Middlesex_revised,"COVID_RevisedDataset_2021-12-02.csv", row.names = FALSE)

#--------------------------------------------------------------------------------------------------#
##### DoW Effects vs. Full Study Period - Tests #####
#--------------------------------------------------------------------------------------------------#

COVID_master_Middlesex_revised$weekday <- factor(COVID_master_Middlesex_revised$weekday, levels=c("Sunday","Monday","Tuesday","Wednesday",
                                                                                                  "Thursday","Friday","Saturday"))

COVID_master_Middlesex_revised <- within(COVID_master_Middlesex_revised, weekday <- relevel(weekday, ref = "Sunday"))

full_tests = glm.nb(daily_tests_1M ~ weekday + T1T_ts + I(T1T_ts**2) + T2T_ts + I(T2T_ts**2) + T3T_ts + I(T3T_ts**2) + 
                T4T_ts + I(T4T_ts**2) + T5T_ts + I(T5T_ts**2) + T6T_ts + I(T6T_ts**2) + T7T_ts + I(T7T_ts**2) + 
                T8T_ts + I(T8T_ts**2) + T9T_ts + I(T9T_ts**2) + T10T_ts + I(T10T_ts**2), data = COVID_master_Middlesex_revised)
summary(full_tests)

exp_tests = tidy(full_tests, exponentiate = T, conf.int = T)
view(exp_tests)

COVID_master_Middlesex_revised$full_tests = full_tests[["fitted.values"]]

write.csv(exp_tests,"Tests_Full.csv", row.names = FALSE)

#--------------------------------------------------------------------------------------------------#
##### DoW Effects vs. Full Study Period - Cases #####
#--------------------------------------------------------------------------------------------------#

COVID_master_Middlesex_revised$weekday <- factor(COVID_master_Middlesex_revised$weekday, levels=c("Sunday","Monday","Tuesday","Wednesday",
                                                                                                  "Thursday","Friday","Saturday"))

COVID_master_Middlesex_revised <- within(COVID_master_Middlesex_revised, weekday <- relevel(weekday, ref = "Sunday"))

full_cases = glm.nb(daily_cases_1M ~ weekday + T1C_ts + I(T1C_ts**2) + T2C_ts + I(T2C_ts**2) + T3C_ts + I(T3C_ts**2) + 
                      T4C_ts + I(T4C_ts**2) + T5C_ts + I(T5C_ts**2) + T6C_ts + I(T6C_ts**2) + T7C_ts + I(T7C_ts**2) + 
                      T8C_ts + I(T8C_ts**2), data = COVID_master_Middlesex_revised)
summary(full_cases)

exp_cases = tidy(full_cases, exponentiate = T, conf.int = T)
view(exp_cases)

COVID_master_Middlesex_revised$full_cases = full_cases[["fitted.values"]]

write.csv(exp_cases,"Cases_Full.csv", row.names = FALSE)

#--------------------------------------------------------------------------------------------------#
##### DoW Effects vs. Full Study Period - Deaths #####
#--------------------------------------------------------------------------------------------------#

COVID_master_Middlesex_revised$weekday <- factor(COVID_master_Middlesex_revised$weekday, levels=c("Sunday","Monday","Tuesday","Wednesday",
                                                                                                  "Thursday","Friday","Saturday"))

COVID_master_Middlesex_revised <- within(COVID_master_Middlesex_revised, weekday <- relevel(weekday, ref = "Sunday"))

full_deaths = glm.nb(daily_deaths_1M ~ weekday + T1D_ts + I(T1D_ts**2) + T2D_ts + I(T2D_ts**2) + T3D_ts + I(T3D_ts**2) + 
                      T4D_ts + I(T4D_ts**2) + T5D_ts + I(T5D_ts**2) + T6D_ts + I(T6D_ts**2) + T7D_ts + I(T7D_ts**2) + 
                      T8D_ts + I(T8D_ts**2), data = COVID_master_Middlesex_revised)
summary(full_deaths)

exp_deaths = tidy(full_deaths, exponentiate = T, conf.int = T)
view(exp_deaths)

COVID_master_Middlesex_revised$full_deaths = full_deaths[["fitted.values"]]

write.csv(exp_deaths,"Deaths_Full.csv", row.names = FALSE)

#--------------------------------------------------------------------------------------------------#
##### DoW Effects vs. Policy Phase - Tests #####
#--------------------------------------------------------------------------------------------------#

COVID_master_Middlesex_revised$weekday <- factor(COVID_master_Middlesex_revised$weekday, levels=c("Sunday","Monday","Tuesday","Wednesday",
                                                                                                  "Thursday","Friday","Saturday"))

COVID_master_Middlesex_revised <- within(COVID_master_Middlesex_revised, weekday <- relevel(weekday, ref = "Sunday"))

#----------------------------------------------------------#
## Phase 1: 22 January 2020 - 14 March 2020

tests1 = COVID_master_Middlesex_revised %>% filter(phase == "A")

count(tests1, CP_tests_all)

tests_p1 = glm.nb(daily_tests_1M ~ weekday + T1T_ts + I(T1T_ts**2), data = tests1)
summary(tests_p1)

exp_tests1 = tidy(tests_p1, exponentiate = T, conf.int = T)
view(exp_tests1)

write.csv(exp_tests1,"Tests_Phase1.csv", row.names = FALSE)

#----------------------------------------------------------#
## Phase 2: 15 March 2020 - 17 May 2020

tests2 = COVID_master_Middlesex_revised %>% filter(phase == "B")

count(tests2, CP_tests_all)

tests_p2 = glm.nb(daily_tests_1M ~ weekday + T1T_ts + I(T1T_ts**2) + T2T_ts + I(T2T_ts**2), data = tests2)
summary(tests_p2)

exp_tests2 = tidy(tests_p2, exponentiate = T, conf.int = T)
view(exp_tests2)

write.csv(exp_tests2,"Tests_Phase2.csv", row.names = FALSE)

#----------------------------------------------------------#
## Phase 3: 18 May 2020 - 01 July 2020

tests3 = COVID_master_Middlesex_revised %>% filter(phase == "C")

count(tests3, CP_tests_all)

tests_p3 = glm.nb(daily_tests_1M ~ weekday + T2T_ts + I(T2T_ts**2) + T3T_ts + I(T3T_ts**2), data = tests3)
summary(tests_p3)

exp_tests3 = tidy(tests_p3, exponentiate = T, conf.int = T)
view(exp_tests3)

write.csv(exp_tests3,"Tests_Phase3.csv", row.names = FALSE)

#----------------------------------------------------------#
## Phase 4: 02 July 2020 - 28 September 2020

tests4 = COVID_master_Middlesex_revised %>% filter(phase == "D")

count(tests4, CP_tests_all)

tests_p4 = glm.nb(daily_tests_1M ~ weekday + T3T_ts + I(T3T_ts**2) + T4T_ts + I(T4T_ts**2) + T5T_ts + I(T5T_ts**2), data = tests4)
summary(tests_p4)

exp_tests4 = tidy(tests_p4, exponentiate = T, conf.int = T)
view(exp_tests4)

write.csv(exp_tests4,"Tests_Phase4.csv", row.names = FALSE)

#----------------------------------------------------------#
## Phase 5: 29 September 2020 - 07 December 2020

tests5 = COVID_master_Middlesex_revised %>% filter(phase == "E")

count(tests5, CP_tests_all)

tests_p5 = glm.nb(daily_tests_1M ~ weekday + T5T_ts + I(T5T_ts**2) + T6T_ts + I(T6T_ts**2), data = tests5)
summary(tests_p5)

exp_tests5 = tidy(tests_p5, exponentiate = T, conf.int = T)
view(exp_tests5)

write.csv(exp_tests5,"Tests_Phase5.csv", row.names = FALSE)

#----------------------------------------------------------#
## Phase 6: 08 December 2020 - 24 February 2021

tests6 = COVID_master_Middlesex_revised %>% filter(phase == "F")

count(tests6, CP_tests_all)

tests_p6 = glm.nb(daily_tests_1M ~ weekday + T6T_ts + I(T6T_ts**2), data = tests6)
summary(tests_p6)

exp_tests6 = tidy(tests_p6, exponentiate = T, conf.int = T)
view(exp_tests6)

write.csv(exp_tests6,"Tests_Phase6.csv", row.names = FALSE)

#----------------------------------------------------------#
## Phase 7: 25 February 2021 - 17 March 2021

tests7 = COVID_master_Middlesex_revised %>% filter(phase == "G")

count(tests7, CP_tests_all)

tests_p7 = glm.nb(daily_tests_1M ~ weekday + T6T_ts + I(T6T_ts**2) + T7T_ts + I(T7T_ts**2), data = tests7)
summary(tests_p7)

exp_tests7 = tidy(tests_p7, exponentiate = T, conf.int = T)
view(exp_tests7)

write.csv(exp_tests7,"Tests_Phase7.csv", row.names = FALSE)

#----------------------------------------------------------#
## Phase 8: 18 March 2021 - 27 May 2021

tests8 = COVID_master_Middlesex_revised %>% filter(phase == "H")

count(tests8, CP_tests_all)

tests_p8 = glm.nb(daily_tests_1M ~ weekday + T7T_ts + I(T7T_ts**2) + T8T_ts + I(T8T_ts**2), data = tests8)
summary(tests_p8)

exp_tests8 = tidy(tests_p8, exponentiate = T, conf.int = T)
view(exp_tests8)

write.csv(exp_tests8,"Tests_Phase8.csv", row.names = FALSE)

#----------------------------------------------------------#
## Phase 9: 28 May 2021 - 07 November 2021

tests9 = COVID_master_Middlesex_revised %>% filter(phase == "I")

count(tests9, CP_tests_all)

tests_p9 = glm.nb(daily_tests_1M ~ weekday + T8T_ts + I(T8T_ts**2) + T9T_ts + I(T9T_ts**2) + T10T_ts + I(T10T_ts**2), data = tests9)
summary(tests_p9)

exp_tests9 = tidy(tests_p9, exponentiate = T, conf.int = T)
view(exp_tests9)

write.csv(exp_tests9,"Tests_Phase9.csv", row.names = FALSE)

#--------------------------------------------------------------------------------------------------#
##### DoW Effects vs. Policy Phase - Cases #####
#--------------------------------------------------------------------------------------------------#

COVID_master_Middlesex_revised$weekday <- factor(COVID_master_Middlesex_revised$weekday, levels=c("Sunday","Monday","Tuesday","Wednesday",
                                                                                                  "Thursday","Friday","Saturday"))

COVID_master_Middlesex_revised <- within(COVID_master_Middlesex_revised, weekday <- relevel(weekday, ref = "Sunday"))

#----------------------------------------------------------#
## Phase 1: 22 January 2020 - 14 March 2020

cases1 = COVID_master_Middlesex_revised %>% filter(phase == "A")

count(cases1, CP_cases_all)

cases_p1 = glm.nb(daily_cases_1M ~ weekday + T1C_ts + I(T1C_ts**2), data = cases1)
summary(cases_p1)

exp_cases1 = tidy(cases_p1, exponentiate = T, conf.int = T)
view(exp_cases1)

write.csv(exp_cases1,"Cases_Phase1.csv", row.names = FALSE)

#----------------------------------------------------------#
## Phase 2: 15 March 2020 - 17 May 2020

cases2 = COVID_master_Middlesex_revised %>% filter(phase == "B")

count(cases2, CP_cases_all)

cases_p2 = glm.nb(daily_cases_1M ~ weekday + T1C_ts + I(T1C_ts**2) + T2C_ts + I(T2C_ts**2), data = cases2)
summary(cases_p2)

exp_cases2 = tidy(cases_p2, exponentiate = T, conf.int = T)
view(exp_cases2)

write.csv(exp_cases2,"Cases_Phase2.csv", row.names = FALSE)

#----------------------------------------------------------#
## Phase 3: 18 May 2020 - 01 July 2020

cases3 = COVID_master_Middlesex_revised %>% filter(phase == "C")

count(cases3, CP_cases_all)

cases_p3 = glm.nb(daily_cases_1M ~ weekday + T2C_ts + I(T2C_ts**2), data = cases3)
summary(cases_p3)

exp_cases3 = tidy(cases_p3, exponentiate = T, conf.int = T)
view(exp_cases3)

write.csv(exp_cases3,"Cases_Phase3.csv", row.names = FALSE)

#----------------------------------------------------------#
## Phase 4: 02 July 2020 - 28 September 2020

cases4 = COVID_master_Middlesex_revised %>% filter(phase == "D")

count(cases4, CP_cases_all)

cases_p4 = glm.nb(daily_cases_1M ~ weekday + T2C_ts + I(T2C_ts**2) + T3C_ts + I(T3C_ts**2), data = cases4)
summary(cases_p4)

exp_cases4 = tidy(cases_p4, exponentiate = T, conf.int = T)
view(exp_cases4)

write.csv(exp_cases4,"Cases_Phase4.csv", row.names = FALSE)

#----------------------------------------------------------#
## Phase 5: 29 September 2020 - 07 December 2020

cases5 = COVID_master_Middlesex_revised %>% filter(phase == "E")

count(cases5, CP_cases_all)

cases_p5 = glm.nb(daily_cases_1M ~ weekday + T3C_ts + I(T3C_ts**2), data = cases5)
summary(cases_p5)

exp_cases5 = tidy(cases_p5, exponentiate = T, conf.int = T)
view(exp_cases5)

write.csv(exp_cases5,"Cases_Phase5.csv", row.names = FALSE)

#----------------------------------------------------------#
## Phase 6: 08 December 2020 - 24 February 2021

cases6 = COVID_master_Middlesex_revised %>% filter(phase == "F")

count(cases6, CP_cases_all)

cases_p6 = glm.nb(daily_cases_1M ~ weekday + T3C_ts + I(T3C_ts**2) + T4C_ts + I(T4C_ts**2), data = cases6)
summary(cases_p6)

exp_cases6 = tidy(cases_p6, exponentiate = T, conf.int = T)
view(exp_cases6)

write.csv(exp_cases6,"Cases_Phase6.csv", row.names = FALSE)

#----------------------------------------------------------#
## Phase 7: 25 February 2021 - 17 March 2021

cases7 = COVID_master_Middlesex_revised %>% filter(phase == "G")

count(cases7, CP_cases_all)

cases_p7 = glm.nb(daily_cases_1M ~ weekday + T4C_ts + I(T4C_ts**2) + T5C_ts + I(T5C_ts**2), data = cases7)
summary(cases_p7)

exp_cases7 = tidy(cases_p7, exponentiate = T, conf.int = T)
view(exp_cases7)

write.csv(exp_cases7,"Cases_Phase7.csv", row.names = FALSE)

#----------------------------------------------------------#
## Phase 8: 18 March 2021 - 27 May 2021

cases8 = COVID_master_Middlesex_revised %>% filter(phase == "H")

count(cases8, CP_cases_all)

cases_p8 = glm.nb(daily_cases_1M ~ weekday + T5C_ts + I(T5C_ts**2) + T6C_ts + I(T6C_ts**2), data = cases8)
summary(cases_p8)

exp_cases8 = tidy(cases_p8, exponentiate = T, conf.int = T)
view(exp_cases8)

write.csv(exp_cases8,"Cases_Phase8.csv", row.names = FALSE)

#----------------------------------------------------------#
## Phase 9: 28 May 2021 - 07 November 2021

cases9 = COVID_master_Middlesex_revised %>% filter(phase == "I")

count(cases9, CP_cases_all)

cases_p9 = glm.nb(daily_cases_1M ~ weekday + T6C_ts + I(T6C_ts**2) + T7C_ts + I(T7C_ts**2) + T8C_ts + I(T8C_ts**2), data = cases9)
summary(cases_p9)

exp_cases9 = tidy(cases_p9, exponentiate = T, conf.int = T)
view(exp_cases9)

write.csv(exp_cases9,"Cases_Phase9.csv", row.names = FALSE)

#--------------------------------------------------------------------------------------------------#
##### DoW Effects vs. Policy Phase - Deaths #####
#--------------------------------------------------------------------------------------------------#

COVID_master_Middlesex_revised$weekday <- factor(COVID_master_Middlesex_revised$weekday, levels=c("Sunday","Monday","Tuesday","Wednesday",
                                                                                                  "Thursday","Friday","Saturday"))

COVID_master_Middlesex_revised <- within(COVID_master_Middlesex_revised, weekday <- relevel(weekday, ref = "Sunday"))

#----------------------------------------------------------#
## Phase 1: 22 January 2020 - 14 March 2020

deaths1 = COVID_master_Middlesex_revised %>% filter(phase == "A")

count(deaths1, CP_deaths_all)

deaths_p1 = glm.nb(daily_deaths_1M ~ weekday + T1D_ts + I(T1D_ts**2), data = deaths1)
summary(deaths_p1)

exp_deaths1 = tidy(deaths_p1, exponentiate = T, conf.int = T)
view(exp_deaths1)

write.csv(exp_deaths1,"Deaths_Phase1.csv", row.names = FALSE)

#----------------------------------------------------------#
## Phase 2: 15 March 2020 - 17 May 2020

deaths2 = COVID_master_Middlesex_revised %>% filter(phase == "B")

count(deaths2, CP_deaths_all)

deaths_p2 = glm.nb(daily_deaths_1M ~ weekday + T1D_ts + I(T1D_ts**2) + T2D_ts + I(T2D_ts**2), data = deaths2)
summary(deaths_p2)

exp_deaths2 = tidy(deaths_p2, exponentiate = T, conf.int = T)
view(exp_deaths2)

write.csv(exp_deaths2,"Deaths_Phase2.csv", row.names = FALSE)

#----------------------------------------------------------#
## Phase 3: 18 May 2020 - 01 July 2020

deaths3 = COVID_master_Middlesex_revised %>% filter(phase == "C")

count(deaths3, CP_deaths_all)

deaths_p3 = glm.nb(daily_deaths_1M ~ weekday + T2D_ts + I(T2D_ts**2), data = deaths3)
summary(deaths_p3)

exp_deaths3 = tidy(deaths_p3, exponentiate = T, conf.int = T)
view(exp_deaths3)

write.csv(exp_deaths3,"Deaths_Phase3.csv", row.names = FALSE)

#----------------------------------------------------------#
## Phase 4: 02 July 2020 - 28 September 2020

deaths4 = COVID_master_Middlesex_revised %>% filter(phase == "D")

count(deaths4, CP_deaths_all)

deaths_p4 = glm.nb(daily_deaths_1M ~ weekday + T2D_ts + I(T2D_ts**2) + T3D_ts + I(T3D_ts**2) + T4D_ts + I(T4D_ts**2), data = deaths4)
summary(deaths_p4)

exp_deaths4 = tidy(deaths_p4, exponentiate = T, conf.int = T)
view(exp_deaths4)

write.csv(exp_deaths4,"Deaths_Phase4.csv", row.names = FALSE)

#----------------------------------------------------------#
## Phase 5: 29 September 2020 - 07 December 2020

deaths5 = COVID_master_Middlesex_revised %>% filter(phase == "E")

count(deaths5, CP_deaths_all)

deaths_p5 = glm.nb(daily_deaths_1M ~ weekday + T4D_ts + I(T4D_ts**2), data = deaths5)
summary(deaths_p5)

exp_deaths5 = tidy(deaths_p5, exponentiate = T, conf.int = T)
view(exp_deaths5)

write.csv(exp_deaths5,"Deaths_Phase5.csv", row.names = FALSE)

#----------------------------------------------------------#
## Phase 6: 08 December 2020 - 24 February 2021

deaths6 = COVID_master_Middlesex_revised %>% filter(phase == "F")

count(deaths6, CP_deaths_all)

deaths_p6 = glm.nb(daily_deaths_1M ~ weekday + T4D_ts + I(T4D_ts**2) + T5D_ts + I(T5D_ts**2), data = deaths6)
summary(deaths_p6)

exp_deaths6 = tidy(deaths_p6, exponentiate = T, conf.int = T)
view(exp_deaths6)

write.csv(exp_deaths6,"Deaths_Phase6.csv", row.names = FALSE)

#----------------------------------------------------------#
## Phase 7: 25 February 2021 - 17 March 2021

deaths7 = COVID_master_Middlesex_revised %>% filter(phase == "G")

count(deaths7, CP_deaths_all)

deaths_p7 = glm.nb(daily_deaths_1M ~ weekday + T5D_ts + I(T5D_ts**2), data = deaths7)
summary(deaths_p7)

exp_deaths7 = tidy(deaths_p7, exponentiate = T, conf.int = T)
view(exp_deaths7)

write.csv(exp_deaths7,"Deaths_Phase7.csv", row.names = FALSE)

#----------------------------------------------------------#
## Phase 8: 18 March 2021 - 27 May 2021

deaths8 = COVID_master_Middlesex_revised %>% filter(phase == "H")

count(deaths8, CP_deaths_all)

deaths_p8 = glm.nb(daily_deaths_1M ~ weekday + T5D_ts + I(T5D_ts**2), data = deaths8)
summary(deaths_p8)

exp_deaths8 = tidy(deaths_p8, exponentiate = T, conf.int = T)
view(exp_deaths8)

write.csv(exp_deaths8,"Deaths_Phase8.csv", row.names = FALSE)

#----------------------------------------------------------#
## Phase 9: 28 May 2021 - 07 November 2021

deaths9 = COVID_master_Middlesex_revised %>% filter(phase == "I")

count(deaths9, CP_deaths_all)

deaths_p9 = glm.nb(daily_deaths_1M ~ weekday + T5D_ts + I(T5D_ts**2) + T6D_ts + I(T6D_ts**2) + T7D_ts + I(T7D_ts**2) + T8D_ts + I(T8D_ts**2), data = deaths9)
summary(deaths_p9)

exp_deaths9 = tidy(deaths_p9, exponentiate = T, conf.int = T)
view(exp_deaths9)

write.csv(exp_deaths9,"Deaths_Phase9.csv", row.names = FALSE)

#--------------------------------------------------------------------------------------------------#
##### Create Final DoW Effects Table #####
#--------------------------------------------------------------------------------------------------#
DoWEffects_forest = 
  # Tests
  mutate(exp_tests, outcome = "Tests", phase = "Overall") %>%
  rbind(mutate(exp_tests2, outcome = "Tests", phase = "B")) %>%
  rbind(mutate(exp_tests3, outcome = "Tests", phase = "C")) %>%
  rbind(mutate(exp_tests4, outcome = "Tests", phase = "D")) %>%
  rbind(mutate(exp_tests5, outcome = "Tests", phase = "E")) %>%
  rbind(mutate(exp_tests6, outcome = "Tests", phase = "F")) %>%
  rbind(mutate(exp_tests7, outcome = "Tests", phase = "G")) %>%
  rbind(mutate(exp_tests8, outcome = "Tests", phase = "H")) %>%
  rbind(mutate(exp_tests9, outcome = "Tests", phase = "I")) %>%
  # Cases
  rbind(mutate(exp_cases, outcome = "Cases", phase = "Overall")) %>%
  rbind(mutate(exp_cases2, outcome = "Cases", phase = "B")) %>%
  rbind(mutate(exp_cases3, outcome = "Cases", phase = "C")) %>%
  rbind(mutate(exp_cases4, outcome = "Cases", phase = "D")) %>%
  rbind(mutate(exp_cases5, outcome = "Cases", phase = "E")) %>%
  rbind(mutate(exp_cases6, outcome = "Cases", phase = "F")) %>%
  rbind(mutate(exp_cases7, outcome = "Cases", phase = "G")) %>%
  rbind(mutate(exp_cases8, outcome = "Cases", phase = "H")) %>%
  # Deaths
  rbind(mutate(exp_deaths, outcome = "Deaths", phase = "Overall")) %>%
  rbind(mutate(exp_deaths2, outcome = "Deaths", phase = "B")) %>%
  rbind(mutate(exp_deaths3, outcome = "Deaths", phase = "C")) %>%
  rbind(mutate(exp_deaths4, outcome = "Deaths", phase = "D")) %>%
  rbind(mutate(exp_deaths5, outcome = "Deaths", phase = "E")) %>%
  rbind(mutate(exp_deaths6, outcome = "Deaths", phase = "F")) %>%
  rbind(mutate(exp_deaths7, outcome = "Deaths", phase = "G")) %>%
  rbind(mutate(exp_deaths8, outcome = "Deaths", phase = "H")) %>%
  # Clean up the table
  filter(startsWith(term, "weekday")) %>%
  mutate(dow = str_remove(term, "weekday")) %>%
  select(phase, outcome, dow, estimate, conf.low, conf.high)

write.csv(DoWEffects_forest, "COVID_DoWEffects_forest.csv", row.names = F)

#--------------------------------------------------------------------------------------------------#
##### Prep for Figures 1 & 2 #####
#--------------------------------------------------------------------------------------------------#

COVID_master_Middlesex_visuals <- read.csv("COVID_RevisedDataset_2021-12-02.csv")
COVID_master_Middlesex_visuals$date = as.Date(COVID_master_Middlesex_visuals$date)

# Pre-set simple, pretty theme
pretty <- theme(panel.grid.major = element_blank(),
                panel.grid.minor = element_blank(),
                panel.background = element_blank(),
                axis.line = element_line(colour = "black"))

# Create dataframe with start and end dates for testing critical periods (for background colors in plots)
CP_tests_dates = COVID_master_Middlesex_visuals %>% group_by(CP_tests_all) %>% summarise(CP_date = min(date))
CP_tests_rects = data.frame(
  xstart = CP_tests_dates$CP_date,
  xend = c(CP_tests_dates$CP_date[-1], max(COVID_master_Middlesex_visuals$date)))

# Create dataframe with start and end dates for case critical periods (for background colors in plots)
CP_cases_dates = COVID_master_Middlesex_visuals %>% group_by(CP_cases_all) %>% summarise(CP_date = min(date))
CP_cases_rects = data.frame(
  xstart = CP_cases_dates$CP_date,
  xend = c(CP_cases_dates$CP_date[-1], max(COVID_master_Middlesex_visuals$date)))

# Create dataframe with start and end dates for death critical periods (for background colors in plots)
CP_deaths_dates = COVID_master_Middlesex_visuals %>% group_by(CP_deaths_all) %>% summarise(CP_date = min(date))
CP_deaths_rects = data.frame(
  xstart = CP_deaths_dates$CP_date,
  xend = c(CP_deaths_dates$CP_date[-1], max(COVID_master_Middlesex_visuals$date)))

# Create dataframe with start and end dates of policy phases (for background colors in plots)
policy_dates = COVID_master_Middlesex_visuals %>% group_by(phase) %>% summarise(policy_date = min(date))
policy_effect_rects = data.frame(
  xstart = policy_dates$policy_date,
  xend = c(policy_dates$policy_date[-1], max(COVID_master_Middlesex_visuals$date)),
  Stringency = c("Level 0", "Level 5", "Level 4", "Level 3", "Level 2", "Level 3", "Level 2", "Level 1", "Level 0"))

stringency_colors = c("Level 0" = "#66bd63", "Level 5" = "#f46d43", "Level 4" = "#fdae61", "Level 3" = "#fee08b", 
                      "Level 2" = "#ffffbf", "Level 1" = "#a6d96a")

#--------------------------------------------------------------------------------------------------#
##### Figure 1 #####
#--------------------------------------------------------------------------------------------------#

#----------------------------------------------------------#
# Top - Tests

tests_ts <- ggplot(COVID_master_Middlesex_visuals) +
  geom_rect(data = CP_tests_rects, aes(xmin = xstart, xmax = xend, ymin = -Inf, ymax = Inf), alpha = 0.7,
            fill = c(rep_len(c("#fa9fb5","#9ecae1"),nrow(CP_tests_rects)))) +
  geom_col(aes(x=date, y=daily_tests_1M)) + 
  geom_line(aes(x=date,y=tests_smooth21), size=1.5, color="red") +
  theme(plot.margin=unit(c(2,8,2,2), "mm"), text = element_text(size=14), axis.text = element_text(size=10),
        legend.position = "none") + 
  scale_y_continuous(expand = c(0,0), breaks=c(0,2000,4000,6000,8000,10000), limits=c(0,11000)) + 
  scale_x_date(breaks = "2 months", limits = as.Date(c('2020-03-02', '2021-11-07')), expand=c(0.005,0)) + 
  xlab("") + ylab("Tests/1,000,000 Persons") + pretty + theme(axis.title.x=element_blank(), axis.text.x=element_blank())
tests_ts

#----------------------------------------------------------#
# Middle - Cases

cases_ts <- ggplot(COVID_master_Middlesex_visuals) +
  geom_rect(data = CP_cases_rects, aes(xmin = xstart, xmax = xend, ymin = -Inf, ymax = Inf), alpha = 0.7,
            fill = c(rep_len(c("#fa9fb5","#9ecae1"),7), "#f0f0f0")) +
  geom_col(aes(x=date, y=daily_cases_1M)) + 
  geom_line(aes(x=date,y=cases_smooth21), size=1.5, color="red") +
  theme(plot.margin=unit(c(2,8,2,2), "mm"), text = element_text(size=14), axis.text = element_text(size=10),
        legend.position = "none") + 
  scale_y_continuous(expand = c(0,0), breaks=c(0,200,400,600,800,1000), limits=c(0,1100)) + 
  scale_x_date(breaks = "2 months", limits = as.Date(c('2020-03-02', '2021-11-07')), expand=c(0.005,0)) + 
  xlab("") + ylab("Cases/1,000,000 Persons") + pretty + theme(axis.title.x=element_blank(), axis.text.x=element_blank())
cases_ts

#----------------------------------------------------------#
# Bottom - Deaths

deaths_ts <- ggplot(COVID_master_Middlesex_visuals) +
  geom_rect(data = CP_deaths_rects, aes(xmin = xstart, xmax = xend, ymin = -Inf, ymax = Inf), alpha = 0.7,
            fill = c("#fa9fb5","#9ecae1", "#f0f0f0","#fa9fb5","#9ecae1", "#f0f0f0","#fa9fb5","#9ecae1")) +
  geom_col(aes(x=date, y=daily_deaths_1M)) + 
  geom_line(aes(x=date,y=deaths_smooth21), size=1.5, color="red") +
  theme(plot.margin=unit(c(2,8,2,2), "mm"), text = element_text(size=14), axis.text = element_text(size=10),
        legend.position = "none") + 
  scale_y_continuous(expand = c(0,0), breaks=c(0,10,20,30,40,50), limits=c(0,50)) + 
  scale_x_date(breaks = "3 months", limits = as.Date(c('2020-03-02', '2021-11-07')), expand=c(0.005,0)) + 
  xlab("Calendar Date [YYYY-MM-DD]") + ylab("Deaths/1,000,000 Persons\n") + pretty
deaths_ts

#----------------------------------------------------------#
# Combined Plot

fig1 = egg::ggarrange(plots=list(tests_ts, cases_ts, deaths_ts), heights=c(1,1,1), nrow=3, ncol=1, align="hv")
png(file = "Figure1.png", res = 200, width = 7.5, height = 9, units = "in")
fig1
dev.off()

### Figure1: W=900, H=870

#--------------------------------------------------------------------------------------------------#
##### Figure 2 #####
#--------------------------------------------------------------------------------------------------#

#----------------------------------------------------------#
# Regression Analyses - Tests

mod1 = glm.nb(daily_tests_1M ~ weekday + T1T_ts + I(T1T_ts**2) + T2T_ts + I(T2T_ts**2) + T3T_ts + I(T3T_ts**2) + 
                T4T_ts + I(T4T_ts**2) + T5T_ts + I(T5T_ts**2) + T6T_ts + I(T6T_ts**2) + T7T_ts + I(T7T_ts**2) + 
                T8T_ts + I(T8T_ts**2) + T9T_ts + I(T9T_ts**2) + T10T_ts + I(T10T_ts**2), data = COVID_master_Middlesex_visuals)
summary(mod1)
df = tidy(mod1, exponentiate = T, conf.int = T)

COVID_master_Middlesex_visuals$fitted_tests = mod1[["fitted.values"]]

#----------------------------------------------------------#
# Creating Time Series

tests_fit <- ggplot(COVID_master_Middlesex_visuals) +
  geom_rect(data = policy_effect_rects, aes(xmin = xstart, xmax = xend, ymin = -Inf, ymax = Inf, fill = Stringency)) +
  scale_fill_manual(values = stringency_colors) +
  geom_col(aes(x=date, y=daily_tests_1M)) + 
  geom_line(aes(x=date,y=fitted_tests), size=0.7, color="black") +
  labs(y="Tests/1,000,000 Persons\n") + scale_y_continuous(expand = c(0,0), breaks=c(0,2000,4000,6000,8000,10000), limits=c(0,11000)) +
  scale_x_date(breaks = "3 months", limits = as.Date(c('2020-03-02', '2021-11-07')), expand=c(0.005,0)) + 
  xlab("") + ylab("Tests/1,000,000 Persons") + pretty + 
  theme(legend.position = "none", axis.title.x=element_blank(), axis.text.x=element_blank(),
        plot.margin=unit(c(0,8,2,1), "mm"), text = element_text(size=14), axis.text = element_text(size=10))
tests_fit

#----------------------------------------------------------#
# Creating Derivative Break Points

tests_deriv <- ggplot() +
  geom_rect(data = CP_tests_rects, aes(xmin = xstart, xmax = xend, ymin = -Inf, ymax = Inf), alpha = 0.7,
            fill = c(rep_len(c("#fa9fb5","#9ecae1"),nrow(CP_tests_rects)))) +
  ylab("") + scale_y_continuous(expand = c(0,0), limits=c(0,10)) + scale_x_date(breaks = "2 months", limits = as.Date(c('2020-03-02', '2021-11-07')), expand=c(0.005,0)) + 
  xlab("") + pretty + theme(legend.position = "none", plot.margin=unit(c(0,0,-1,0), "mm")) +
  theme(axis.title=element_blank(), axis.text=element_blank(), axis.ticks=element_blank(), axis.line = element_blank())
tests_deriv

#----------------------------------------------------------#
# Regression Analyses - Cases

mod2 = glm.nb(daily_cases_1M ~ weekday + T1C_ts + I(T1C_ts**2) + T2C_ts + I(T2C_ts**2) + T3C_ts + I(T3C_ts**2) + 
                T4C_ts + I(T4C_ts**2) + T5C_ts + I(T5C_ts**2) + T6C_ts + I(T6C_ts**2) + T7C_ts + I(T7C_ts**2) + 
                T8C_ts + I(T8C_ts**2), data = COVID_master_Middlesex_visuals)
summary(mod2)
df = tidy(mod2, exponentiate = T, conf.int = T)

COVID_master_Middlesex_visuals$fitted_cases = mod2[["fitted.values"]]

#----------------------------------------------------------#
# Creating Time Series

cases_fit <- ggplot(COVID_master_Middlesex_visuals) +
  geom_rect(data = policy_effect_rects, aes(xmin = xstart, xmax = xend, ymin = -Inf, ymax = Inf, fill = Stringency)) +
  scale_fill_manual(values = stringency_colors) +
  geom_col(aes(x=date, y=daily_cases_1M)) + 
  geom_line(aes(x=date,y=fitted_cases), size=0.7, color="black") +
  labs(y="Cases/1,000,000 Persons\n") + scale_y_continuous(expand = c(0,0), breaks=c(0,200,400,600,800,1000,1200), limits=c(0,1200)) +
  scale_x_date(breaks = "3 months", limits = as.Date(c('2020-03-02', '2021-11-07')), expand=c(0.005,0)) + 
  xlab("") + ylab("Cases/1,000,000 Persons") + pretty + 
  theme(legend.position = "none", axis.title.x=element_blank(), axis.text.x=element_blank(), 
        plot.margin=unit(c(0,8,2,1), "mm"), text = element_text(size=14), axis.text = element_text(size=10))
cases_fit

#----------------------------------------------------------#
# Creating Derivative Break Points

cases_deriv <- ggplot() +
  geom_rect(data = CP_cases_rects, aes(xmin = xstart, xmax = xend, ymin = -Inf, ymax = Inf), alpha = 0.7,
            fill = c(rep_len(c("#fa9fb5","#9ecae1"),7), "#f0f0f0")) +
  ylab("") + scale_y_continuous(expand = c(0,0), limits=c(0,10)) + scale_x_date(breaks = "2 months", limits = as.Date(c('2020-03-02', '2021-11-07')), expand=c(0.005,0)) + 
  xlab("") + pretty + theme(legend.position = "none", plot.margin=unit(c(0,0,-1,0), "mm")) +
  theme(axis.title=element_blank(), axis.text=element_blank(), axis.ticks=element_blank(), axis.line = element_blank())
cases_deriv

#----------------------------------------------------------#
# Regression Analyses - Deaths

mod3 = glm.nb(daily_deaths_1M ~ weekday + T1D_ts + I(T1D_ts**2) + T2D_ts + I(T2D_ts**2) + T3D_ts + I(T3D_ts**2) + 
                T4D_ts + I(T4D_ts**2) + T5D_ts + I(T5D_ts**2) + T6D_ts + I(T6D_ts**2) + T7D_ts + I(T7D_ts**2) + 
                T8D_ts + I(T8D_ts**2), data = COVID_master_Middlesex_visuals)
summary(mod3)
df = tidy(mod3, exponentiate = T, conf.int = T)

COVID_master_Middlesex_visuals$fitted_deaths = mod3[["fitted.values"]]

#----------------------------------------------------------#
# Creating Time Series

deaths_fit <- ggplot(COVID_master_Middlesex_visuals) +
  geom_rect(data = policy_effect_rects, aes(xmin = xstart, xmax = xend, ymin = -Inf, ymax = Inf, fill = Stringency)) +
  scale_fill_manual(values = stringency_colors) +
  geom_col(aes(x=date, y=daily_deaths_1M)) + geom_line(aes(x=date,y=fitted_deaths), size=0.7, color="black") +
  labs(y="Cases/1,000,000 Persons\n") + scale_y_continuous(expand = c(0,0), breaks=c(0,10,20,30,40,50), limits=c(0,50)) +
  scale_x_date(breaks = "3 months", limits = as.Date(c('2020-03-02', '2021-11-07')), expand=c(0.005,0)) + 
  xlab("Calendar Date [YYYY-MM-DD]") + ylab("Deaths/1,000,000 Persons\n") + pretty + 
  theme(plot.margin=unit(c(0,8,2,1), "mm"), text = element_text(size=14), axis.text = element_text(size=10),
        legend.position = "bottom") +
  guides(fill = guide_legend(nrow = 1))
deaths_fit

#----------------------------------------------------------#
# Creating Derivative Break Points

deaths_deriv <- ggplot() +
  geom_rect(data = CP_deaths_rects, aes(xmin = xstart, xmax = xend, ymin = -Inf, ymax = Inf), alpha = 0.7,
            fill = c("#fa9fb5","#9ecae1", "#f0f0f0","#fa9fb5","#9ecae1", "#f0f0f0","#fa9fb5","#9ecae1")) +
  ylab("") + scale_y_continuous(expand = c(0,0), limits=c(0,10)) + scale_x_date(breaks = "2 months", limits = as.Date(c('2020-03-02', '2021-11-07')), expand=c(0.005,0)) + 
  xlab("") + pretty + theme(legend.position = "none", plot.margin=unit(c(0,0,-1,0), "mm")) +
  theme(axis.title=element_blank(), axis.text=element_blank(), axis.ticks=element_blank(), axis.line = element_blank())
deaths_deriv

#----------------------------------------------------------#
# All Panels - Figure 2

all_plots = egg::ggarrange(plots=list(tests_deriv, tests_fit, cases_deriv, cases_fit, deaths_deriv, deaths_fit),
                           heights=c(0.10,1,0.10,1,0.10,1), nrow=6, ncol=1, align="hv")
png(file = "Figure2.png", res = 200, width = 7.5, height = 9, units = "in")
all_plots
dev.off()

#--------------------------------------------------------------------------------------------------#
##### Figure 3 #####
#--------------------------------------------------------------------------------------------------#

#----------------------------------------------------------#
### Loading Data

DoWEffects_forest = read.csv("COVID_DoWEffects_forest.csv")

#----------------------------------------------------------#
### Creating Colors and Releveling

dow_color = c("#9A90CD", "#A26769", "#E3AE83", "#C0DFA1", "#75A5CF", "#332E3C")
dow_color2 = c("#BD897E", "#97331F", "#9FC2CC", "#005C69", "#81667A", "#3A0842")


DoWEffects_forest$phase = factor(DoWEffects_forest$phase)
DoWEffects_forest$phase = relevel(DoWEffects_forest$phase, ref = "Overall")
DoWEffects_forest$dow <- factor(DoWEffects_forest$dow, 
                                levels=c("Monday","Tuesday","Wednesday","Thursday","Friday","Saturday"))
DoWEffects_forest$outcome <- factor(DoWEffects_forest$outcome,
                                    levels = c("Tests", "Cases", "Deaths"))

#----------------------------------------------------------#
### Creating Plot
DoWEffects_fp <- ggplot(data=subset(DoWEffects_forest, phase!="A"), 
       aes(x = fct_rev(phase), y = estimate, ymin = conf.low, ymax = conf.high, color = fct_rev(dow))) +
  geom_hline(yintercept = 1, linetype=2) +
  geom_pointrange(position = position_dodge(width = 0.9), size = 0.4) +
  geom_vline(xintercept = c(1.5,2.5,3.5,4.5,5.5,6.5,7.5,8.5)) +
  coord_flip() +
  theme_bw() + 
  scale_color_manual(values = dow_color2) +
  theme(panel.grid.major.y = element_blank(), legend.position = "bottom",
        text = element_text(size=14), axis.text = element_text(size=10)) +
  guides(color = guide_legend(reverse = T, nrow = 1)) +
  labs(x = "Stringency Phase", y = "Risk Ratio (95% Confidence Interval)", color = element_blank()) +
  facet_wrap(~outcome)
png(file = "Figure3_colors2.png", res = 200, width = 7.5, height = 9, units = "in")
DoWEffects_fp
dev.off()
